@@ -280,6 +280,7 @@ ImagePipelineTypeDef = TypedDict(
         "name": str,
         "description": str,
         "platform": Literal["Windows", "Linux"],
+        "enhancedImageMetadataEnabled": bool,
         "imageRecipeArn": str,
         "infrastructureConfigurationArn": str,
         "distributionConfigurationArn": str,
@@ -421,6 +422,8 @@ ImageTypeDef = TypedDict(
         "name": str,
         "version": str,
         "platform": Literal["Windows", "Linux"],
+        "enhancedImageMetadataEnabled": bool,
+        "osVersion": str,
         "state": ImageStateTypeDef,
         "imageRecipe": ImageRecipeTypeDef,
         "sourcePipelineName": str,
@@ -525,6 +528,7 @@ ImageSummaryTypeDef = TypedDict(
         "name": str,
         "version": str,
         "platform": Literal["Windows", "Linux"],
+        "osVersion": str,
         "state": ImageStateTypeDef,
         "owner": str,
         "dateCreated": str,
@@ -579,6 +583,7 @@ ImageVersionTypeDef = TypedDict(
         "name": str,
         "version": str,
         "platform": Literal["Windows", "Linux"],
+        "osVersion": str,
         "owner": str,
         "dateCreated": str,
     },
